Package: MKomics
Version: 0.8
Date: 2026-05-07
Title: Omics Data Analysis
Authors@R: person("Matthias", "Kohl", role = c("aut", "cre"),
                  email = "Matthias.Kohl@stamats.de", 
                  comment = c(ORCID = "0000-0001-9514-8910"))
Author: Matthias Kohl [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-9514-8910>)
Maintainer: Matthias Kohl <Matthias.Kohl@stamats.de>
Depends: R(>= 4.0.0)
Imports: stats, utils, graphics, grDevices, RColorBrewer, robustbase,
        limma, grid, circlize, ComplexHeatmap
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
Description: Similarity plots based on correlation and median absolute deviation (MAD); adjusting colors for heatmaps; aggregate technical replicates; calculate pairwise fold-changes and log fold-changes; compute one- and two-way ANOVA; simplified interface to package 'limma' (Ritchie et al. (2015), <doi:10.1093/nar/gkv007> ) for moderated t-test and one-way ANOVA; Hamming and Levenshtein (edit) distance of strings as well as optimal alignment scores for global (Needleman-Wunsch) and local (Smith-Waterman) alignments with constant gap penalties (Merkl and Waack (2009), ISBN:978-3-527-32594-8).
License: LGPL-3
URL: https://www.stamats.de/
NeedsCompilation: no
Packaged: 2026-05-07 11:51:39 UTC; kohlm
Repository: CRAN
Date/Publication: 2026-05-07 13:31:19 UTC
Built: R 4.6.0; ; 2026-05-07 14:07:15 UTC; unix
