import("stats")
importFrom("utils", "combn")
importFrom("graphics", "layout", "image", "axis", "box", "par")
importFrom("grDevices", "colorRampPalette")
importFrom("robustbase", "covMcd", "covOGK")
importFrom("RColorBrewer", "brewer.pal")
importFrom("limma", "lmFit", "makeContrasts", "contrasts.fit", "eBayes",
           "topTable")
importFrom("grid", "unit", "gpar")
importFrom("circlize", "colorRamp2")
importFrom("ComplexHeatmap", "Heatmap", "draw")
export(corDist,
       corPlot,
       corPlot2,
       heatmapCol,
       madMatrix,
       madPlot,
       madPlot2,
       mod.t.test,
       mod.oneway.test,
       oneWayAnova,
       pairwise.logfc,
       pairwise.fc,
       pairwise.mod.t.test,
       repMeans,
       simPlot,
       simPlot2,
       stringDist,
       stringSim,
       traceBack,
       twoWayAnova)
